@@ -12,11 +12,12 @@ use Carp;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 
-our $VERSION = 0.002;
+our $VERSION = 0.003;
+
+extends qw/App::BitBucketCli::Base/;
 
 has [qw/
     state
-    id
     toRef
     closed
     version
@@ -26,10 +27,8 @@ has [qw/
     updatedDate
     createdDate
     title
-    links
     reviewers
     participants
-    link
     author
 /] => (
     is  => 'rw',
@@ -100,11 +99,6 @@ sub to_data {
     };
 }
 
-sub TO_JSON {
-    my ($self) = @_;
-    return { %{ $self } };
-}
-
 1;
 
 __END__
@@ -115,7 +109,7 @@ App::BitBucketCli::PullRequest - Stores details about a pull request
 
 =head1 VERSION
 
-This documentation refers to App::BitBucketCli::PullRequest version 0.002
+This documentation refers to App::BitBucketCli::PullRequest version 0.003
 
 =head1 SYNOPSIS
 
